Outline – Samplics Documentation
Description: Documentation of the Python package Samplics for statistical design and analysis of complex samples

# Outline

Samplics is a Python package designed to be a comprehensive tool for selecting, weighting and analyzing survey sample data obtained from complex designs. The main objective of this tutorial is to take the user through the Samplics’ APIs main features. We hope that after going through the tutorial, the user will have a good understanding of the APIs and be able to analyze complex sample data using samplics. It is assumed that the user has a basic understanding of Python syntax.

Note

This tutorial is not intended to teach survey sampling methods. To learn survey sampling methods, we refer the user to the reference textbook (Lohr 2021), the UNStats Handbook 2005, Designing Household Survey Samples: Practical Guidelines, and the reference material mentioned throughout this tutorial.

The tutorial is organized into several sections. The sections are fairly independent and users can directly consult the section(s) of interest. However, we recommend that all first time users start with the Section on the Datasets before diving into other sections.

Section 1: Datasets
Section 2: Sample size calculation
Section 2.1: Sample size for stage design
Section 3: Sample selection
Section 4: Sample weigthing
Section 4.1: Sample weight sdjustment
Section 4.2: Replicate weights
Section 5: Population parameters estimation
Section 5.1: Tabulation
Section 5.2: Unit T-test
Section 6: Categorical data analysis
Section 6.1: Tabulation
Section 6.2: Unit T-test
Section 7: Small area estimation (SAE)
Section 7.1: Area level modeling
Section 7.2: Unit level modeling

## References

Lohr, Sharon L. 2021. Sampling: Design and Analysis, Third Edition. Chapman; Hall/CRC. https://doi.org/https://doi.org/10.1201/9780429298899.